@@ -2,7 +2,7 @@ package App::moduleshere;
 
 use warnings;
 use strict;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 1;
 
@@ -15,6 +15,7 @@ App::moduleshere - copy modules(.pm) to cwd or somewhere
 =head1 SYNOPSIS
 
     mhere Carp                                    # copy Carp.pm in @INC to cwd
+    mhere -r Carp                                 # copy Carp and all under it.
     mhere Carp CGI                                # copy both Carp.pm and CGI.pm
     APP_MODULES_HERE=outlib mhere Carp            # copy to outlib dir in cwd
     mhere -l outlib Carp                          # ditto
@@ -28,7 +29,7 @@ The precedence order is: C<-l>, env C<APP_MODULES_HERE> and cwd.
 By default, it will copy to cwd.
 
 It's first written when I tried to trace a bug in one of my modules which 
-led me to the other module(let's call it C<Foo> here) in C<@INC>.
+led me to another module(let's call it C<Foo> here) in C<@INC>.
 
 So I ran C<perldoc -l Foo> to find its path, edited it to add more debug
 info, forced save it(happy that I had the write permission),
@@ -51,7 +52,7 @@ No bugs have been reported.
 
 =head1 AUTHOR
 
-<sunnavy>  C<< <<sunnavy@bestpractical.com>> >>
+sunnavy  C<< sunnavy@bestpractical.com >>
 
 
 =head1 LICENCE AND COPYRIGHT
